@@ -7,17 +7,9 @@ use MIME::Base64;
 use URI;
 use REST::Client;
 
-=head1 NAME
+# ABSTRACT: A wrapper around the Jenkins API
 
-Jenkins::API - A wrapper around the Jenkins API
-
-=head1 VERSION
-
-Version 0.11
-
-=cut
-
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 has base_url => (is => 'ro', isa => Str, required => 1);
 has api_key => (is => 'ro', isa => Maybe[Str], required => 0);
@@ -38,6 +30,197 @@ has '_client' => (
     }
 );
 
+
+sub create_job
+{
+    my ($self, $name, $job_config) = @_;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments('createItem');
+    $uri->query_form( name => $name );
+    # curl -XPOST http://moe:8080/createItem?name=test -d@config.xml -v -H Content-Type:text/xml
+    $self->_client->POST($uri->path_query, $job_config, { 'Content-Type' => 'text/xml' });
+    return $self->_client->responseCode() eq '200';
+}
+
+sub delete_project
+{
+    my ($self, $name) = @_;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments('job', $name, 'doDelete');
+    $self->_client->POST($uri->path_query, undef, { 'Content-Type' => 'text/xml' });
+    return $self->_client->responseCode() eq '302';
+}
+
+sub trigger_build
+{
+  my $self = shift;
+  return $self->_trigger_build('build', @_);
+}
+
+sub trigger_build_with_parameters
+{
+  my $self = shift;
+  return $self->_trigger_build('buildWithParameters', @_);
+}
+
+sub _trigger_build
+{
+    my $self = shift;
+    my $build_url = shift;
+    my $job = shift;
+    my $extra_params = shift;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments('job', $job, $build_url);
+    $uri->query_form($extra_params) if $extra_params;
+    $self->_client->POST($uri->path_query);
+    return $self->_client->responseCode eq '201';
+}
+
+sub project_config
+{
+    my $self = shift;
+    my $job = shift;
+    my $extra_params = shift;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments('job', $job, 'config.xml');
+    $uri->query_form($extra_params) if $extra_params;
+    $self->_client->GET($uri->path_query);
+    return $self->_client->responseContent;
+}
+
+sub set_project_config
+{
+    my $self = shift;
+    my $job = shift;
+    my $config = shift;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments('job', $job, 'config.xml');
+    $self->_client->POST($uri->path_query, $config, { 'Content-Type' => 'text/xml' });
+    return $self->_client->responseCode() eq '200';
+}
+
+sub check_jenkins_url
+{
+    my $self = shift;
+    $self->_client->GET('/');
+    return $self->_client->responseCode() eq '200'
+        && $self->_client->responseHeader('X-Jenkins');
+}
+
+sub build_queue
+{
+    my $self = shift;
+    return $self->_json_api(['queue', 'api','json'], @_);
+}
+
+sub load_statistics
+{
+    my $self = shift;
+    return $self->_json_api(['overallLoad', 'api','json'], @_);
+}
+
+sub get_job_details
+{
+    my $self = shift;
+    my $job_name = shift;
+    return $self->_json_api(['job', $job_name, 'api', 'json'], @_);
+}
+
+sub current_status
+{
+    my $self = shift;
+    return $self->_json_api(['api','json'], @_);
+}
+
+sub view_status
+{
+    my $self = shift;
+    my $view = shift;
+    return $self->_json_api(['view', $view, 'api', 'json'], @_);
+}
+
+sub _json_api
+{
+    my $self = shift;
+    my $uri_parts = shift;
+    my $args = shift;
+    my $extra_params = $args->{extra_params};
+    my $bits = $args->{path_parts} || [];
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments(@$bits, @$uri_parts);
+    $uri->query_form($extra_params) if $extra_params;
+
+    $self->_client->GET($uri->path_query);
+    die 'Invalid response' unless $self->_client->responseCode eq '200';
+    # NOTE: my server returns UTF8, if this turns out to be a broken
+    # assumption read the Content-Type header.
+    my $data = JSON->new->utf8->decode($self->_client->responseContent());
+    return $data;
+}
+
+sub general_call
+{
+    my $self = shift;
+    my $uri_parts = shift;
+    my $args = shift;
+
+    my $extra_params = $args->{extra_params};
+    my $method = $args->{method} || 'GET';
+    my $decode_json = exists $args->{decode_json} ? $args->{decode_json} : 1;
+    my $expected_response = $args->{expected_response_code} || 200;
+
+    my $uri = URI->new($self->base_url);
+    $uri->path_segments(@$uri_parts);
+    $uri->query_form($extra_params) if $extra_params;
+
+    $self->_client->$method($uri->path_query);
+    die 'Invalid response' unless $self->_client->responseCode eq $expected_response;
+    my $response = $self->_client->responseContent();
+    if($decode_json)
+    {
+        $response = JSON->new->utf8->decode($response);
+    }
+    return $response;
+}
+
+
+sub response_code
+{
+    my $self = shift;
+    return $self->_client->responseCode;
+}
+
+
+sub response_content
+{
+    my $self = shift;
+    return $self->_client->responseContent;
+}
+
+
+
+1; # End of Jenkins::API
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Jenkins::API - A wrapper around the Jenkins API
+
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
 This is a wrapper around the Jenkins API.  
@@ -109,7 +292,7 @@ It returns the version number of the Jenkins server if it is running.
 
     $jenkins->check_jenkins_url;
     # 1.460
-    
+
 =head2 current_status
 
 Returns the current status of the server as returned by the API.  This 
@@ -268,7 +451,6 @@ To just get the job info from the view for example you can do essentially the sa
     #   ]
     # }
 
-
 =head2 trigger_build
 
 Trigger a build,
@@ -393,194 +575,17 @@ Defaulted to 200
 
 =back
 
-=cut
-
-sub create_job
-{
-    my ($self, $name, $job_config) = @_;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments('createItem');
-    $uri->query_form( name => $name );
-    # curl -XPOST http://moe:8080/createItem?name=test -d@config.xml -v -H Content-Type:text/xml
-    $self->_client->POST($uri->path_query, $job_config, { 'Content-Type' => 'text/xml' });
-    return $self->_client->responseCode() eq '200';
-}
-
-sub delete_project
-{
-    my ($self, $name) = @_;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments('job', $name, 'doDelete');
-    $self->_client->POST($uri->path_query, undef, { 'Content-Type' => 'text/xml' });
-    return $self->_client->responseCode() eq '302';
-}
-
-sub trigger_build
-{
-  my $self = shift;
-  return $self->_trigger_build('build', @_);
-}
-
-sub trigger_build_with_parameters
-{
-  my $self = shift;
-  return $self->_trigger_build('buildWithParameters', @_);
-}
-
-sub _trigger_build
-{
-    my $self = shift;
-    my $build_url = shift;
-    my $job = shift;
-    my $extra_params = shift;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments('job', $job, $build_url);
-    $uri->query_form($extra_params) if $extra_params;
-    $self->_client->POST($uri->path_query);
-    return $self->_client->responseCode eq '302';
-}
-
-sub project_config
-{
-    my $self = shift;
-    my $job = shift;
-    my $extra_params = shift;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments('job', $job, 'config.xml');
-    $uri->query_form($extra_params) if $extra_params;
-    $self->_client->GET($uri->path_query);
-    return $self->_client->responseContent;
-}
-
-sub set_project_config
-{
-    my $self = shift;
-    my $job = shift;
-    my $config = shift;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments('job', $job, 'config.xml');
-    $self->_client->POST($uri->path_query, $config, { 'Content-Type' => 'text/xml' });
-    return $self->_client->responseCode() eq '200';
-}
-
-sub check_jenkins_url
-{
-    my $self = shift;
-    $self->_client->GET('/');
-    return $self->_client->responseCode() eq '200'
-        && $self->_client->responseHeader('X-Jenkins');
-}
-
-sub build_queue
-{
-    my $self = shift;
-    return $self->_json_api(['queue', 'api','json'], @_);
-}
-
-sub load_statistics
-{
-    my $self = shift;
-    return $self->_json_api(['overallLoad', 'api','json'], @_);
-}
-
-sub get_job_details
-{
-    my $self = shift;
-    my $job_name = shift;
-    return $self->_json_api(['job', $job_name, 'api', 'json'], @_);
-}
-
-sub current_status
-{
-    my $self = shift;
-    return $self->_json_api(['api','json'], @_);
-}
-
-sub view_status
-{
-    my $self = shift;
-    my $view = shift;
-    return $self->_json_api(['view', $view, 'api', 'json'], @_);
-}
-
-sub _json_api
-{
-    my $self = shift;
-    my $uri_parts = shift;
-    my $args = shift;
-    my $extra_params = $args->{extra_params};
-    my $bits = $args->{path_parts} || [];
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments(@$bits, @$uri_parts);
-    $uri->query_form($extra_params) if $extra_params;
-
-    $self->_client->GET($uri->path_query);
-    die 'Invalid response' unless $self->_client->responseCode eq '200';
-    # NOTE: my server returns UTF8, if this turns out to be a broken
-    # assumption read the Content-Type header.
-    my $data = JSON->new->utf8->decode($self->_client->responseContent());
-    return $data;
-}
-
-sub general_call
-{
-    my $self = shift;
-    my $uri_parts = shift;
-    my $args = shift;
-
-    my $extra_params = $args->{extra_params};
-    my $method = $args->{method} || 'GET';
-    my $decode_json = exists $args->{decode_json} ? $args->{decode_json} : 1;
-    my $expected_response = $args->{expected_response_code} || 200;
-
-    my $uri = URI->new($self->base_url);
-    $uri->path_segments(@$uri_parts);
-    $uri->query_form($extra_params) if $extra_params;
-
-    $self->_client->$method($uri->path_query);
-    die 'Invalid response' unless $self->_client->responseCode eq $expected_response;
-    my $response = $self->_client->responseContent();
-    if($decode_json)
-    {
-        $response = JSON->new->utf8->decode($response);
-    }
-    return $response;
-}
-
 =head2 response_code
 
 This method returns the HTTP response code from our last request to 
 the Jenkins server.  This may be useful when an error occurred.
 
-=cut
-
-sub response_code
-{
-    my $self = shift;
-    return $self->_client->responseCode;
-}
-
 =head2 response_content
 
 This method returns the content of the HTTP response from our 
 last request to the Jenkins server.  This may be useful when 
 an error occurrs.
 
-=cut
-
-sub response_content
-{
-    my $self = shift;
-    return $self->_client->responseContent;
-}
-
-
 =head1 BUGS
 
 The API wrapper doesn't deal with jenkins installations not running from
@@ -593,14 +598,12 @@ at L<https://github.com/colinnewell/Jenkins-API/issues/new>.  I will
 be notified, and then you'll automatically be notified of progress 
 on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Jenkins::API
 
-
 You can also look for information at:
 
 =over 4
@@ -653,10 +656,6 @@ With thanks to Nick Hu for adding the trigger_build_with_parameters method.
 
 Alex Kulbiy for the auth support and David Steinbrunner for some Makefile love.
 
-=head1 AUTHOR
-
-Colin Newell <colin.newell@gmail.com>
-
 =head1 CONTRIBUTORS
 
 =over 4
@@ -687,18 +686,15 @@ Dave Horner L<https://dave.thehorners.com>
 
 =back
 
-=head1 LICENSE AND COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2012-2015 Colin Newell.
+Colin Newell <colin.newell@gmail.com>
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+=head1 COPYRIGHT AND LICENSE
 
-See http://dev.perl.org/licenses/ for more information.
+This software is copyright (c) 2012-2017 by Colin Newell.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of Jenkins::API
-
